@@ -20,14 +20,15 @@ theme = WebpackThemeBundle(
                 "invenio-theme-tuw-mobilemenu": "./js/invenio_theme_tuw/mobilemenu/index.js",
                 "invenio-theme-tuw-messages": "./js/invenio_theme_tuw/messages/index.js",
                 "invenio-theme-tuw-pdf-preview": "./js/invenio_theme_tuw/pdf-preview/index.js",
+                "invenio-theme-tuw-landing-page": "./js/invenio_theme_tuw/landing_page/index.js",
             },
             "dependencies": {
                 "jquery": "^3.2.1",
             },
             "aliases": {
                 "themes/tuw": "less/invenio_theme_tuw/theme",
-                "../../less/invenio_theme_tuw/theme/assets": "../static"
-            }
+                "../../less/invenio_theme_tuw/theme/assets": "../static",
+            },
         },
     },
 )
